@@ -9,3 +9,7 @@ plotly::`%>%`
 #' @importFrom plotly subplot
 #' @export
 plotly::subplot
+
+#' @importFrom plotly plotly_json
+#' @export
+plotly::plotly_json
